# Changes for bmi-topography

## 0.8.5 (2024-08-18)

-  Check example notebooks (#75)
- Simplify the test CI workflow (#74)
- Cancel in-progress CI workflows on new push (#73)
- Use pre-commit for linting and formatting (#72)
- De-lint project files (#71)


## 0.8.4 (2024-03-28)

- Update docs build (#68)
- Set minimum python>=3.10 (#67)
- Link to project contributing and code of conduct docs (#65)


## 0.8.3 (2023-12-18)

- Build and test with Python 3.12 (#60)
- Remove setuptools files in favor of pyproject.toml (#59)
- Fix failing docs build (#58)
- Use nox in CI testing (#54)


## 0.8.2 (2023-02-06)

- Fix problem getting CRS info for AAIGrid type (#53)


## 0.8.1 (2023-01-27)

- Run test CI on Windows with Python 3.10 (#52)
- Use nox instead of make for building and testing project (#51)
- Update project metadata files (#50)
- Use rio accessor for geospatial information (#47)
- Update contents of source and binary distributions (#46)


## 0.8 (2022-07-05)

- Switch from xarray to rioxarray (#45)
- Move metadata from setup.cfg to pyproject.toml (#44)


## 0.7.1 (2022-06-03)

- Provide a better reason for 401 errors (#41)


## 0.7 (2022-03-24)

- Support all OpenTopography global datasets (#39)
- Create test matrix of datasets and file types (#38)


## 0.6 (2022-02-17)

- Use dashes in command line options (#36)
- Use a demo API key if a user key can't be found (#34)


## 0.5.1 (2022-02-15)

- Document use of OpenTopography API key (#33)
- Add text to exception raised when API key is missing (#32)
- Use new black syntax (#31)


## 0.5 (2022-01-25)

- Use an API key when requesting OpenTopography data (#25)
- Add python 3.10 to tests (#24)
- Address technical debt (#22)


## 0.4 (2021-09-03)

- Support ALOS World 3D 30m products (#13)
- Support .asc and .img files (#14)
- Add format job to CI
- Use CITATION.cff file


## 0.3.2 (2021-04-23)

- Add citation recommendation with DOI
- Fix typos, update text in example notebooks
- Create CREDITS.md and rearrange docs


## 0.3.1 (2021-03-04)

- Install with conda
- Include shell script demonstrating CLI


## 0.3 (2021-02-25)

- Update README with overview and install instructions
- Write documentation


## 0.2 (2021-02-24)

- Implement BMI for Topography class from template generated by `bmipy-render`
- Include sample config file and Jupyter Notebook to demo BMI
- Add CI with GitHub Actions


## 0.1.1 (2021-02-22)

- Add Makefile rule to test upload to TestPyPI
- Test upload to TestPyPI


## 0.1 (2021-02-22)

- Create base library that calls OpenTopography API
- Create CLI for library
- Write tests for library and CLI
- Include demo Jupyter Notebook for library
